<?php
use GeoIp2\Database\Reader;

class Wp_Dxp_Condition_NinjaForms_Completed_Form_Submission extends Wp_Dxp_Base_Condition {

	public $identifier = 'ninja_forms_completed_form_submission';

	public $category = 'Ninja Forms';

	/**
	 * Constructor
	 */
	public function __construct() {
		parent::__construct();

		$this->description = __( 'User has submitted a form', 'wp-dxp' );

		$this->comparators = [
			'equals' => _x( 'Is', 'Comparator', 'wp-dxp' ),
		];

		$this->comparisonValues = [
			'true'  => _x( 'True', 'Comparison value', 'wp-dxp' ),
			'false' => _x( 'False', 'Comparison value', 'wp-dxp' ),
		];
	}

	/**
	 * Test data against condition
	 * @param  string $comparator
	 * @return boolean
	 */
	public function matchesCriteria($comparator, $value, $action, $meta = [])
	{
		switch ($comparator) {
			case 'equals':
				return $this->comparatorEquals($value);
		}

		return false;
	}

	/**
	 * "Equal" test
	 * @return boolean
	 */
	public function comparatorEquals($value)
	{
		global $wpdb;

		if (is_user_logged_in()) {
			$sql = $wpdb->prepare("SELECT COUNT(id) FROM {$wpdb->prefix}posts WHERE post_author = %s AND `post_type` = 'nf_sub'", get_current_user_id());
			$submissionCount = $wpdb->get_var($sql);

		    if ($value == 'true') {
		    	return $submissionCount > 0;
		    }

		    return $submissionCount == 0;
		}

		return false;
	}

	/**
	 * Array of dependencies for the condition to be used
	 * @return array
	 */
	public function dependencies()
	{
		return [
			Wp_Dxp_Dependency_Ninja_Forms_Activated::getInstance(),
		];
	}
}