<?php
use GeoIp2\Database\Reader;

class Wp_Dxp_Condition_WooCommerce_Completed_Purchase extends Wp_Dxp_Base_Condition {

	public $identifier = 'woocommerce_completed_purchase';

	public $category = 'WooCommerce';

	/**
	 * Constructor
	 */
	public function __construct() {
		parent::__construct();

		$this->description = __( 'Visitor has completed purchase', 'wp-dxp' );

		$this->comparators = [
			'equals' => _x( 'Is', 'Comparator', 'wp-dxp' ),
		];

		$this->comparisonValues = [
			'true'  => _x( 'True', 'Comparison value', 'wp-dxp' ),
			'false' => _x( 'False', 'Comparison value', 'wp-dxp' ),
		];
	}

	/**
	 * Test data against condition
	 * @param  string $comparator
	 * @return boolean
	 */
	public function matchesCriteria($comparator, $value, $action, $meta = [])
	{
		switch ($comparator) {
			case 'equals':
				return $this->comparatorEquals($value);
		}

		return false;
	}

	/**
	 * "Equal" test
	 * @return boolean
	 */
	public function comparatorEquals($value)
	{
		$customerOrders = get_posts([
	        'numberposts' => 1,
	        'meta_key'    => '_customer_user',
	        'meta_value'  => get_current_user_id(),
	        'post_type'   => 'shop_order', // WC orders post type
	        'post_status' => 'wc-completed' // Only orders with status "completed"
	    ]);

	    if ($value == 'true') {
	    	return count($customerOrders) > 0;
	    }

	    return count($customerOrders) == 0;
	}

	/**
	 * Array of dependencies for the condition to be used
	 * @return array
	 */
	public function dependencies()
	{
		return [
			Wp_Dxp_Dependency_Woocommerce_Activated::getInstance(),
		];
	}
}